@@ -5,7 +5,7 @@ use super::{
   port_close,
   port_send,
   port_send_close,
-  CallResult,
+  Error,
 };
 
 /// The WebAssembly-based PortSender trait. This trait encapsulates sending messages out of a WebAssembly component's ports.
@@ -14,27 +14,27 @@ pub trait PortSender {
   type PayloadType: Serialize;
 
   /// Send a message.
-  fn send(&self, payload: &Self::PayloadType) -> CallResult {
+  fn send(&self, payload: &Self::PayloadType) -> Result<(), Error> {
     port_send(&self.get_name(), v0::Payload::messagepack(payload))
   }
 
   /// Send a message then close the port.
-  fn done(&self, payload: &Self::PayloadType) -> CallResult {
+  fn done(&self, payload: &Self::PayloadType) -> Result<(), Error> {
     port_send_close(&self.get_name(), v0::Payload::messagepack(payload))
   }
 
   /// Send an exception.
-  fn send_exception(&self, message: String) -> CallResult {
+  fn send_exception(&self, message: String) -> Result<(), Error> {
     port_send(&self.get_name(), v0::Payload::Exception(message))
   }
 
   /// Send an exception then close the port.
-  fn done_exception(&self, message: String) -> CallResult {
+  fn done_exception(&self, message: String) -> Result<(), Error> {
     port_send_close(&self.get_name(), v0::Payload::Exception(message))
   }
 
   /// Signal that a job is finished with the port.
-  fn close(&self) -> CallResult {
+  fn close(&self) -> Result<(), Error> {
     port_close(&self.get_name())
   }
 
